@@ -4,7 +4,7 @@ use warnings;
 use base 'CGI::Application';
 
 use vars qw($VERSION);
-$VERSION = '0.001';
+$VERSION = '0.002';
 
 
 # Load recommended plugins by default. 
@@ -78,10 +78,8 @@ The bundled plugins mix the following methods into your controller runmodes:
 
 =head1 DESCRIPTION
 
-CGI::Application::Structured is based on CGI::Application and includes a number of vetted CGIApp plugins.  This project is very similar
-to, and inspired by, Mark Stosberg's L<Titanium> framework and Jaldhar H. Vyas's L<Module::Starter::Plugin::CGIApp> . 
 
-I have taken to heart a comment by Mark Stosberg on the CGIApp mailing list:
+I have taken to heart a recent comment by Mark Stosberg on the CGIApp mailing list:
 
 =over 8
 
@@ -92,7 +90,9 @@ and publish that with a different name."
 
 =back
 
-Titanium takes a very light-weight approach to make running in a CGI environment very fast. CGI::Application::Structured takes a slightly different approach and aims for:
+CGI::Application::Structured, like L<Titanium>, is an opinionated framework, based on CGI::Application.  Both frameworks includes a number of vetted CGI-App plugins each of which are well documented and tested.  C::A::Structured, however takes the view that developer time and consistent projects structures can often be more cost-effective than focusing on the highest performance on low cost hosting solutions.  That being said, C::A::Structured can be deployed on CGI, FastCGI or mod_perl based on your needs.
+
+C::A::Structured focuses on:
 
 =over 4
 
@@ -110,7 +110,7 @@ a powerful templating DSL via Template Toolkit integration.
 
 =item *
 
-a integrated Object Relational Mapper
+a integrated Object Relational Mapper, L<DBIx::Class>
 
 =item *
 
@@ -127,23 +127,43 @@ clean url-to-controller mapping by default.
 
 =back
 
+C::A::Structured comes in two packages:
 
+=over 4
 
-CGI::Application::Structured is also different in that it generates a micro-architecture and helper scripts that work within that structure to speed development and maintain project structure. The helper scripts eliminate the tedium of error-prone manual creation of controllers, templates and database mappings.
+=item *
 
-The skeleton app generated by L<cas-starter.pl> generates a base class rather than runnable module.  This is 
-differen than the artifacts generated by titanium-starter.pl.  cas-starter also generates a default 
-'Home' subclass and a CGI::Application::Dispatch instance that is customized to default to the 
-Home subclasses generated 'index' runmode.  
+CGI::Application::Strutured - encapsulates the runtime environment.
 
-L<attainum-starter.pl> also generates the script 'YourApp/script/create_controller.pl'  which will 
-generate additional subclasses of your base module with a default 'index' runmode and a 
-default TT template for that runmode. The provided 'YourApp/script/create_dbic_schema.pl' will generate a DBIx::Class::Schema subclass and a set of 
-DBIx::Class::Result set subclasses for your custom databasse.
+=item *
 
-Finally CGI::Application::Structured aims to be as compatible as possible with L<Catalyst> which also has the plugins which were 
-added to Titanium to form CGI::Application::Structured.
+CGI::Application::Structured::Tools - includes project creation and developemt scripts for developers.
 
+=back
+
+CGI::Application::Structured::Tools are used to generate a micro-architecture and helper scripts that work within that structure to speed development and maintain project structure across development teams and projects. The helper scripts eliminate the tedium of error-prone manual creation of controllers, templates and database mappings and provide a recognizeable structural conventions that reduced stress on the developer when working across multiple apps, or working with other developers code on the same project.
+
+The first script that is used is 'cas-starter.pl'. This script is used to generate the initial project skeleton. The skeleton app contains a base controller class rather than runnable module as would be found in L<Titanium>.  Also generated is a default 'Home' controller subclass and a URL dispatcher that is customized to default to the Home controllers generated 'index' runmode.  
+
+cas-starter.pl also generates additional helper scripts in your projects 'scripts' subdirectory: 
+
+=over 4
+
+=item *
+
+create_controller.pl
+
+=item *
+
+create_dbic_schema.pl
+
+=back 
+
+'create_controller.pl' is used by the developer to generate additional controller subclasses of your base module with a default 'index' runmode and a default TT template for that runmode. 
+
+'create_dbic_schema.pl' generates a DBIx::Class::Schema subclass and a set of resultset subclasses for your database.  These Object Relational Maps (ORM) will greatly simplify and speed database assess and manipulation in the development process.
+
+Finally CGI::Application::Structured aims to be as compatible as possible with L<Catalyst>.  Many plugins used in CGI::Application::Structured are also available for Catalyst, or are even defaults in L<Catalyst>. If your projects needs grow in scope or scale to require Catalyst, porting much of your code will be very easy.
 
 
 =head1 CGI::Application::Structured Tutorial
@@ -159,18 +179,19 @@ CGI::Application::Structured assumes that you have a database that you want to u
 
 =head2 Installation
 
-You will need to install L<CGI::Application::Structured> which provides the runtime requirements.  You will also need to install L<Module::Starter::Plugin::Attanium> which supplies the development environment.
+You will need to install L<CGI::Application::Structured> which provides the runtime requirements.  You will also need to install L<CGI::Application::Structured::Tools> which supplies the development environment.
 
     ~/dev$ sudo cpan
     cpan> install CGI::Application::Structured
           ... ok
-    cpan> install Module::Starter::Plugin::Attanium
+    cpan> install CGI::Application::Structured::Tools
           ... ok
     cpan> exit
 
+
 =cut 
 
-=head2 Creating a Project
+=head2 Creating A Project
 
 
     ~/dev$ cas-starter.pl --module=MyApp1 \
@@ -233,6 +254,7 @@ Using the root account is shown here as a worst-practice.  You should customize
 
 If you do not have a database and want to use an example see "Create Example Database" below before continuing.
 
+For information on advanced configuration see: L<CGI::Application::Plugin::ConfigAuto>
 =cut
 
 =head2 Generate A DBIx::Class Schema For Your Database
@@ -254,6 +276,7 @@ Given the example database shown below your resulting DBIx::Class related files
     lib/MyApp1/DB.pm
 
 
+For more information see: L<CGI::Application::Plugin::DBIC::Schema>, L<DBIx::Class>
 
 =cut
 
@@ -282,9 +305,11 @@ Open your browser and test at
     http://localhost:8060/cgi-bin/index.cgi
 
 
+For more information on the nature of the development server see: L<CGI::Application::Server>
+
 =cut
 
-=head2 Create a new Submodule
+=head2 Create A New Controller
 
 This is where the create_controller.pl helper script comes in very handy.
 As an example we can generate a new module to interact with the Orders table
@@ -337,7 +362,9 @@ Restart server.pl and visit page to see list of orders at:
     
   http://localhost:8060/cgi-bin/orders/list
     
- 
+
+For advanced information on creating controllers, runmodes and templates see: L<CGI::Application::Plugin::AutoRunmode>, L<CGI::Application::Plugin::TT>, L<CGI::Application> and L<Template::Toolkit>.
+
 =cut
 
 =head2 Creating The Example Database (if you don't already have one)
@@ -346,7 +373,7 @@ The L<CGI::Application::Structured> distrubution contains an example sql file th
 example app.  Use the download link at L<CGI::Application::Structured> on CPAN, grab the archive and extract the file from the 'examples' directory of the distribution. 
 
 The script will create the 'myapp1_dev' database, create 2 tables and load a few 
-Notice that the create table statements end with 'engine=InnoDB'.  This is important since our DBIC generator script will create relationships on the perl side ased on the metadata in the database.  The default engine for mysql will not store the relationship metadata and you will then need to hand-craft the relationships at the botton of the generated DB::Result classes.
+Notice that the create table statements end with 'engine=InnoDB'.  This is important since our DBIC generator script will create perl modules to represent database table relationships, based on the metadata in the database.  While the InnoDB engine will work, the default engine for mysql will not store the relationship metadata and you would then need to hand-craft the relationships at the botton of the generated DB::Result classes.
 
 Example:
 
@@ -397,6 +424,7 @@ See documentation for L<DBIx::Class::Manual> for more information on configuring
 
 =head1 Further Reading
 
+See L<CGI::Application::Structured::Tools> for more information on developer tools package.
 
 See L<CGI::Application::Plugin::DBIC::Schema> for more information on accessing DBIx::Class from your CGI::Application::Structured modules.
 
@@ -404,9 +432,12 @@ See L<CGI::Application::Plugin::SuperForm> for form building support that is bui
 
 See L<DBIx::Class::Manual::Intro> for more information on using the powerful ORM included with CGI::Application::Structured.
 
+See L<Template::Toolkit> and L<CGI::Application::Plugin::TT> for more information on advanced templating.
+
 See L<Titanium> and L<CGI::Application> for lots of good ideas and examples that will work with your CGI::Application::Structured app.
 
 
+
 =head1 BUGS
 
 There are no known bugs for this distribution.  
